@@ -3,12 +3,12 @@ setMethod(
           'dmeasure',
           'pomp',
           function (object, y, x, times, params, log = FALSE, ...) {
-            x <- try(
-                     .Call(do_dmeasure,object,y,x,times,params,log),
-                     silent=FALSE
-                     )
-            if (inherits(x,'try-error'))
+            val <- try(
+                       .Call(do_dmeasure,object,y,x,times,params,log),
+                       silent=FALSE
+                       )
+            if (inherits(val,'try-error'))
               stop("dmeasure error: error in user 'dmeasure'",call.=FALSE)
-            x
+            val
           }
           )
